aboutsummaryrefslogtreecommitdiff
path: root/usr.bin/objformat/objformat.c
diff options
context:
space:
mode:
authorJohn Birrell <jb@FreeBSD.org>1998-08-30 20:40:29 +0000
committerJohn Birrell <jb@FreeBSD.org>1998-08-30 20:40:29 +0000
commit8472e43276ee964aeed46e8eb590049b0003d529 (patch)
tree145667326b48afcb8a7681cb4d51acf8b4ccabf6 /usr.bin/objformat/objformat.c
parent3cba8076098977be8a0d111e6e8b862e303be4bb (diff)
Notes
Diffstat (limited to 'usr.bin/objformat/objformat.c')
-rw-r--r--usr.bin/objformat/objformat.c6
1 files changed, 3 insertions, 3 deletions
diff --git a/usr.bin/objformat/objformat.c b/usr.bin/objformat/objformat.c
index 92440d642637..827af6eda1e9 100644
--- a/usr.bin/objformat/objformat.c
+++ b/usr.bin/objformat/objformat.c
@@ -45,8 +45,8 @@ getobjfmt(void)
char *env;
int i;
- /* first hint is /etc/objectformat */
- FILE *fp = fopen("/etc/objectformat", "r");
+ /* first hint is /etc/objformat */
+ FILE *fp = fopen("/etc/objformat", "r");
if (fp) {
char buf[1024];
buf[1023] = '\0';
@@ -59,7 +59,7 @@ getobjfmt(void)
else if (strcmp(buf, "OBJFORMAT=elf") == 0)
objformat_aout = 0;
else
- fprintf(stderr, "Unrecognized line in /etc/objectformat: %s\n", buf);
+ fprintf(stderr, "Unrecognized line in /etc/objformat: %s\n", buf);
}
fclose(fp);
}